@@ -21,23 +21,19 @@
 #include "module.h"
 
 #include <KAboutData>
-#include <KDeclarative/KDeclarative>
 #include <KLocalizedString>
 #include <KPluginFactory>
 
-#include <context.h>
-#include <pulseaudio.h>
-
 #include "version.h"
 
-K_PLUGIN_CLASS_WITH_JSON(KCMPulseAudio, "kcm_pulseaudio.json")
+K_PLUGIN_CLASS_WITH_JSON(KCMPulseAudio, "metadata.json")
 
 KCMPulseAudio::KCMPulseAudio(QObject *parent, const QVariantList &args)
     : KQuickAddons::ConfigModule(parent, args)
 {
     KAboutData *aboutData = new KAboutData("kcm_pulseaudio",
                                            i18nc("@title", "Audio"),
-                                           global_s_versionStringFull,
+                                           QStringLiteral(PLASMAPA_VERSION_STRING),
                                            QStringLiteral(""),
                                            KAboutLicense::LicenseKey::GPL_V3,
                                            i18nc("@info:credit", "Copyright 2015 Harald Sitter"));
